@@ -1,7 +1,6 @@
 /*
-** Copyright (C) 2014-2015 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2010-2013 Sourcefire, Inc.
-** Author: Michael R. Altizer <maltizer@sourcefire.com>
+** Author: Michael R. Altizer <mialtize@cisco.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -30,8 +29,8 @@
 #else
 /* for struct timeavl */
 #include <winsock2.h>
-#include <windows.h>
 #include <ws2tcpip.h>
+#include <windows.h>
 #endif
 
 #ifndef DAQ_SO_PUBLIC
@@ -83,16 +82,27 @@
 #define DAQ_ERROR_AGAIN     -9  /* Try again */
 #define DAQ_READFILE_EOF    -42 /* Hit the end of the file being read! */
 
-#define DAQ_PKT_FLAG_HW_TCP_CS_GOOD     0x1 /* The DAQ module reports that the checksum for this packet is good. */
-#define DAQ_PKT_FLAG_OPAQUE_IS_VALID    0x2 /* The DAQ module actively set the opaque value in the DAQ packet header. */
-#define DAQ_PKT_FLAG_NOT_FORWARDING     0x4 /* The DAQ module will not be actively forwarding this packet
-                                               regardless of the verdict (e.g, Passive or Inline Tap interfaces). */
-#define DAQ_PKT_FLAG_PRE_ROUTING        0x8 /* The packet is being routed via us but packet modifications
-                                                (MAC and TTL) have not yet been made. */
-#define DAQ_PKT_FLAG_SSL_DETECTED	0x10 /* Packet is ssl client hello */
-#define DAQ_PKT_FLAG_SSL_SHELLO	    0x20 /* Packet is ssl server hello */
-#define DAQ_PKT_FLAG_SSL_SERVER_KEYX	0x40 /* Packet is ssl server keyx */
-#define DAQ_PKT_FLAG_SSL_CLIENT_KEYX	0x80 /* Packet is ssl client keyx */
+#define DAQ_PKT_FLAG_HW_TCP_CS_GOOD     0x00001 /* The DAQ module reports that the checksum for this packet is good. */
+#define DAQ_PKT_FLAG_OPAQUE_IS_VALID    0x00002 /* The DAQ module actively set the opaque value in the DAQ packet header. */
+#define DAQ_PKT_FLAG_NOT_FORWARDING     0x00004 /* The DAQ module will not be actively forwarding this packet
+                                                    regardless of the verdict (e.g, Passive or Inline Tap interfaces). */
+#define DAQ_PKT_FLAG_PRE_ROUTING        0x00008 /* The packet is being routed via us but packet modifications
+                                                    (MAC and TTL) have not yet been made. */
+#define DAQ_PKT_FLAG_SSL_DETECTED       0x00010 /* Packet is ssl client hello */
+#define DAQ_PKT_FLAG_SSL_SHELLO         0x00020 /* Packet is ssl server hello */
+#define DAQ_PKT_FLAG_SSL_SERVER_KEYX    0x00040 /* Packet is ssl server keyx */
+#define DAQ_PKT_FLAG_SSL_CLIENT_KEYX    0x00080 /* Packet is ssl client keyx */
+#define DAQ_PKT_FLAG_IGNORE_VLAN        0x00100 /* Ignore vlan tags in the packet */
+#define DAQ_PKT_FLAG_REAL_ADDRESSES     0x00200 /* The real address values in the header are valid */
+#define DAQ_PKT_FLAG_REAL_SIP_V6        0x00400 /* The real source address is IPv6 */
+#define DAQ_PKT_FLAG_REAL_DIP_V6        0x00800 /* The real destination address is IPv6 */
+#define DAQ_PKT_FLAG_FLOWID_IS_VALID    0x01000 /* The DAQ module actively set the flow ID value in the DAQ packet header. */
+#define DAQ_PKT_FLAG_LOCALLY_DESTINED   0x02000 /* The packet is destined for local delivery */
+#define DAQ_PKT_FLAG_LOCALLY_ORIGINATED 0x04000 /* The packet was originated locally */
+#define DAQ_PKT_FLAG_SCRUBBED_TCP_OPTS  0x08000 /* Scrubbed tcp options maybe available */
+#define DAQ_PKT_FLAG_HA_STATE_AVAIL     0x10000 /* HA State is availble for the flow this packet is associated with. */
+#define DAQ_PKT_FLAG_ERROR_PACKET       0x20000 /* Lower level reports that the packet has errors. */
+#define DAQ_PKT_FLAG_RETRY_PACKET       0x40000 /* Packet is from the retry queue. */
 
 /* The DAQ packet header structure passed to DAQ Analysis Functions.
  * This should NEVER be modified by user applications. */
@@ -111,49 +121,70 @@ typedef struct _daq_pkthdr
     uint32_t opaque;        /* Opaque context value from the DAQ module or underlying hardware.
                                Directly related to the opaque value in FlowStats. */
     void *priv_ptr;         /* Private data pointer */
-    uint32_t flow_id;
+    uint32_t flow_id;       /* Flow ID value provided from the DAQ module or underlying hardware. */
     uint16_t address_space_id; /* Unique ID of the address space */
+
+    /* Real values for NAT'ed connections */
+    struct in6_addr real_sIP;
+    struct in6_addr real_dIP;
+    uint16_t n_real_sPort;
+    uint16_t n_real_dPort;
 } DAQ_PktHdr_t;
 
-#define DAQ_METAHDR_TYPE_SOF        0
-#define DAQ_METAHDR_TYPE_EOF        1
-#define DAQ_METAHDR_TYPE_VPN_LOGIN  2
-#define DAQ_METAHDR_TYPE_VPN_LOGOUT 3
+
+/* HA state binary blob descriptor used for DAQ_METAHDR_TYPE_HA_STATE and DAQ_QUERYFLOW_TYPE_HA_STATE. */
+typedef struct _daq_ha_state_data
+{
+    uint32_t length;
+    void *data;
+} DAQ_HA_State_Data_t;
+
+
+/*
+ * Metapacket callback types and definitions.
+ */
+
+#define DAQ_METAHDR_TYPE_SOF        0   /* Start of Flow statistics */
+#define DAQ_METAHDR_TYPE_EOF        1   /* End of Flow statistics */
+#define DAQ_METAHDR_TYPE_VPN_LOGIN  2   /* VPN login info */
+#define DAQ_METAHDR_TYPE_VPN_LOGOUT 3   /* VPN logout info */
+#define DAQ_METAHDR_TYPE_HA_STATE   4   /* HA State blob */
 typedef struct _daq_metahdr
 {
     int type;               /* Type */
 } DAQ_MetaHdr_t;
 
-typedef struct _daq_modflow
-{
-    uint32_t    opaque;     /* */
-} DAQ_ModFlow_t;
-
-#define DAQ_FLOWSTATS_IPV4      0
-#define DAQ_FLOWSTATS_IPV6      1
+/* Flow statistics structure used for DAQ_METAHDR_TYPE_SOF and DAQ_METAHDR_TYPE_EOF. */
 typedef struct _flow_stats
 {
     int32_t ingressZone;
     int32_t egressZone;
     int32_t ingressIntf;
     int32_t egressIntf;
+    /* The IP addresses should be IPv6 or IPv6 representation of IPv4 (::FFFF:<ipv4>) */
     uint8_t initiatorIp[16];
     uint8_t responderIp[16];
     uint16_t initiatorPort;
     uint16_t responderPort;
-    uint8_t protocol;
-    uint8_t version;
-    uint64_t initiatorPkts;
-    uint64_t responderPkts;
-    uint64_t initiatorBytes;
-    uint64_t responderBytes;
     uint32_t opaque;
-    uint16_t vlan_tag;
+    uint64_t initiatorPkts;         /* Not populated for SoF stats. */
+    uint64_t responderPkts;         /* Not populated for SoF stats. */
+    uint64_t initiatorBytes;        /* Not populated for SoF stats. */
+    uint64_t responderBytes;        /* Not populated for SoF stats. */
+    /* QoS related variables */
+    uint64_t initiatorPktsDropped;  /* Not populated for SoF stats. */
+    uint64_t responderPktsDropped;  /* Not populated for SoF stats. */
+    uint64_t initiatorBytesDropped; /* Not populated for SoF stats. */
+    uint64_t responderBytesDropped; /* Not populated for SoF stats. */
+    uint8_t isQoSAppliedOnSrcIntf;  /* Not populated for SoF stats. */
     struct timeval sof_timestamp;
-    struct timeval eof_timestamp;
+    struct timeval eof_timestamp;   /* Not populated for SoF stats. */
+    uint16_t vlan_tag;
     uint16_t address_space_id;
+    uint8_t protocol;
 } Flow_Stats_t, *Flow_Stats_p;
 
+/* VPN session type used by DAQ_VPN_Login_Info_t for DAQ_METAHDR_TYPE_VPN_LOGIN. */
 typedef enum {
     NP_IDFW_VPN_SESSION_TYPE_UNKNOWN = 0,
     NP_IDFW_VPN_SESSION_TYPE_RA_IKEV1 = 1,
@@ -165,21 +196,78 @@ typedef enum {
     NP_IDFW_VPN_SESSION_TYPE_MAX,
 } np_idfw_vpn_session_type_t;
 
-#define DAQ_VPN_INFO_MAX_USER_NAME_LEN  256
+/* VPN logout info used for DAQ_VPN_Login_Info_t and DAQ_METAHDR_TYPE_VPN_LOGOUT. */
 typedef struct _daq_vpn_info
 {
     uint8_t ip[16];
     uint32_t id;
 } DAQ_VPN_Info_t, *DAQ_VPN_Info_p;
 
+/* VPN login info used for DAQ_METAHDR_TYPE_VPN_LOGIN. */
+#define DAQ_VPN_INFO_MAX_USER_NAME_LEN  256
 typedef struct _daq_vpn_login_info
 {
     DAQ_VPN_Info_t info;
     uint32_t os;
-    uint32_t type;
+    np_idfw_vpn_session_type_t type;
     char user[DAQ_VPN_INFO_MAX_USER_NAME_LEN + 1];
 } DAQ_VPN_Login_Info_t, *DAQ_VPN_Login_Info_p;
 
+/*
+ * Flow modification definitions.
+ */
+
+#define DAQ_MODFLOW_TYPE_OPAQUE     1
+#define DAQ_MODFLOW_TYPE_HA_STATE   2
+#define DAQ_MODFLOW_TYPE_SET_QOS_ID 3
+typedef struct _daq_modflow
+{
+    int type;
+    uint32_t length;
+    const void *value;
+} DAQ_ModFlow_t;
+
+
+/*
+ * Flow querying definitions.
+ */
+
+#define DAQ_QUERYFLOW_TYPE_TCP_SCRUBBED_SYN     1
+#define DAQ_QUERYFLOW_TYPE_TCP_SCRUBBED_SYN_ACK 2
+#define DAQ_QUERYFLOW_TYPE_HA_STATE             3
+typedef struct _daq_queryflow
+{
+    int type;
+    uint32_t length;
+    void *value;
+} DAQ_QueryFlow_t;
+
+/* TCP option flags Used by DAQ_TCP_Opts_t. */
+typedef enum
+{
+    DAQ_TCP_OPTS_MSS_CHANGED = 0x01,
+    DAQ_TCP_OPTS_WIN_SCALE_CHANGED = 0x02,
+    DAQ_TCP_OPTS_SACK_CHANGED = 0x04,
+    DAQ_TCP_OPTS_TS_CHANGED = 0x08,
+} DAQ_TCP_Opts_flags_t;
+
+/* This structure contains TCP options before modification by the underlying
+    hardware.  It is used for DAQ_QUERYFLOW_TYPE_TCP_SCRUBBED_SYN and
+    DAQ_QUERYFLOW_TYPE_TCP_SCRUBBED_SYN_ACK. */
+typedef struct daq_tcp_opts_t_
+{
+    uint8_t flags;
+    uint8_t window_scale;
+    uint16_t mss;
+    uint8_t window_scale_position;
+    uint8_t ts_position;
+    uint8_t mss_position;
+    uint8_t sack_ok_position;
+    uint32_t ts_value;
+} DAQ_TCP_Opts_t;
+
+
+/* Packet verdicts returned by DAQ_Analysis_Func_t callbacks. */
 typedef enum {
     DAQ_VERDICT_PASS,       /* Pass the packet. */
     DAQ_VERDICT_BLOCK,      /* Block the packet. */
@@ -187,7 +275,8 @@ typedef enum {
     DAQ_VERDICT_WHITELIST,  /* Pass the packet and fastpath all future packets in the same flow systemwide. */
     DAQ_VERDICT_BLACKLIST,  /* Block the packet and block all future packets in the same flow systemwide. */
     DAQ_VERDICT_IGNORE,     /* Pass the packet and fastpath all future packets in the same flow for this application. */
-    DAQ_VERDICT_RETRY,     /* Hold the packet briefly and resend it to Snort while Snort waits for external response. Drop any new packets received on that flow while holding before sending them to Snort. */
+    DAQ_VERDICT_RETRY,      /* Hold the packet briefly and resend it to Snort while Snort waits for external response.
+                               Drop any new packets received on that flow while holding before sending them to Snort. */
     MAX_DAQ_VERDICT
 } DAQ_Verdict;
 
@@ -237,10 +326,12 @@ typedef struct _daq_stats
 
 #define DAQ_DP_TUNNEL_TYPE_NON_TUNNEL 0
 #define DAQ_DP_TUNNEL_TYPE_GTP_TUNNEL 1
-#define DAQ_DP_TUNNEL_TYPE_OTHER_TUNNEL 2
+#define DAQ_DP_TUNNEL_TYPE_MPLS_TUNNEL 2
+#define DAQ_DP_TUNNEL_TYPE_OTHER_TUNNEL 3
 
 typedef struct _DAQ_DP_key_t {
-    uint32_t af;                /* AF_INET or AF_INET6 */
+    uint16_t src_af;                /* AF_INET or AF_INET6 */
+    uint16_t dst_af;                /* AF_INET or AF_INET6 */
     union {
         struct in_addr src_ip4;
         struct in6_addr src_ip6;
@@ -258,6 +349,19 @@ typedef struct _DAQ_DP_key_t {
     uint16_t vlan_cnots;
 } DAQ_DP_key_t;
 
+typedef struct _DAQ_Data_Channel_Params_t
+{
+    unsigned flags;     /* DAQ_DATA_CHANNEL_* flags*/
+    unsigned timeout_ms;/* timeout of the data channel in milliseconds */
+    unsigned length;    /* [Future] length of the data associated with the data channel */
+    uint8_t* data;      /* [Future] opaque data blob to return with the data channel */
+} DAQ_Data_Channel_Params_t;
+
+/* DAQ module data channel flags */
+#define DAQ_DATA_CHANNEL_FLOAT          0x01 /* the data channel can float to a different snort */
+#define DAQ_DATA_CHANNEL_ALLOW_MULTIPLE 0x02 /* allow multiple connections to use the same data channel entry */
+#define DAQ_DATA_CHANNEL_PERSIST        0x04 /* data channel entry persists even if control channel terminates */
+
 /* DAQ module type flags */
 #define DAQ_TYPE_FILE_CAPABLE   0x01    /* can read from a file */
 #define DAQ_TYPE_INTF_CAPABLE   0x02    /* can open live interfaces */
@@ -266,18 +370,26 @@ typedef struct _DAQ_DP_key_t {
 #define DAQ_TYPE_NO_UNPRIV      0x10    /* can not run unprivileged */
 
 /* DAQ module capability flags */
-#define DAQ_CAPA_NONE           0x000   /* no capabilities */
-#define DAQ_CAPA_BLOCK          0x001   /* can block packets */
-#define DAQ_CAPA_REPLACE        0x002   /* can replace/modify packet data (up to the original data size) */
-#define DAQ_CAPA_INJECT         0x004   /* can inject packets */
-#define DAQ_CAPA_WHITELIST      0x008   /* can whitelist flows */
-#define DAQ_CAPA_BLACKLIST      0x010   /* can blacklist flows */
-#define DAQ_CAPA_UNPRIV_START   0x020   /* can call start() without root privileges */
-#define DAQ_CAPA_BREAKLOOP      0x040   /* can call breakloop() to break acquisition loop */
-#define DAQ_CAPA_BPF            0x080   /* can call set_filter() to establish a BPF */
-#define DAQ_CAPA_DEVICE_INDEX   0x100   /* can consistently fill the device_index field in DAQ_PktHdr */
-#define DAQ_CAPA_INJECT_RAW     0x200   /* injection of raw packets (no layer-2 headers) */
-#define DAQ_CAPA_RETRY          0x400   /* resend packet to Snort after brief delay. */
+#define DAQ_CAPA_NONE           0x00000000   /* no capabilities */
+#define DAQ_CAPA_BLOCK          0x00000001   /* can block packets */
+#define DAQ_CAPA_REPLACE        0x00000002   /* can replace/modify packet data (up to the original data size) */
+#define DAQ_CAPA_INJECT         0x00000004   /* can inject packets */
+#define DAQ_CAPA_WHITELIST      0x00000008   /* can whitelist flows */
+#define DAQ_CAPA_BLACKLIST      0x00000010   /* can blacklist flows */
+#define DAQ_CAPA_UNPRIV_START   0x00000020   /* can call start() without root privileges */
+#define DAQ_CAPA_BREAKLOOP      0x00000040   /* can call breakloop() to break acquisition loop */
+#define DAQ_CAPA_BPF            0x00000080   /* can call set_filter() to establish a BPF */
+#define DAQ_CAPA_DEVICE_INDEX   0x00000100   /* can consistently fill the device_index field in DAQ_PktHdr */
+#define DAQ_CAPA_INJECT_RAW     0x00000200   /* injection of raw packets (no layer-2 headers) */
+#define DAQ_CAPA_RETRY          0x00000400   /* resend packet to Snort after brief delay. */
+#define DAQ_CAPA_DECODE_GTP     0x00000800   /* decodes and tracks flows within GTP. */
+#define DAQ_CAPA_DECODE_TEREDO  0x00001000   /* decodes and tracks flows within Teredo. */
+#define DAQ_CAPA_DECODE_GRE     0x00002000   /* decodes and tracks flows within GRE. */
+#define DAQ_CAPA_DECODE_4IN4    0x00004000   /* decodes and tracks flows of IPv4 within IPv4. */
+#define DAQ_CAPA_DECODE_6IN4    0x00008000   /* decodes and tracks flows of IPv6 within IPv4. */
+#define DAQ_CAPA_DECODE_4IN6    0x00010000   /* decodes and tracks flows of IPv4 within IPv6. */
+#define DAQ_CAPA_DECODE_6IN6    0x00020000   /* decodes and tracks flows of IPv6 within IPv6. */
+#define DAQ_CAPA_DECODE_MPLS    0x00040000   /* decodes and tracks flows within MPLS. */
 
 typedef struct _daq_module DAQ_Module_t;
 
