@@ -22,20 +22,29 @@
 #include "config.h"
 #endif
 
+#include <arpa/inet.h>
+#include <pcap.h>
 #include <stdlib.h>
 #include <string.h>
-#include <pcap.h>
 
 #include "daq.h"
 #include "daq_api.h"
 
-#define DAQ_MOD_VERSION 3
+#define DAQ_MOD_VERSION 4
 
 #define DAQ_NAME "dump"
 #define DAQ_TYPE (DAQ_TYPE_FILE_CAPABLE | DAQ_TYPE_INTF_CAPABLE | \
                   DAQ_TYPE_INLINE_CAPABLE | DAQ_TYPE_MULTI_INSTANCE)
 
-#define DAQ_DUMP_FILE "inline-out.pcap"
+#define DAQ_DUMP_PCAP_FILE "inline-out.pcap"
+#define DAQ_DUMP_TEXT_FILE "inline-out.txt"
+
+typedef enum {
+    DUMP_OUTPUT_NONE = 0x0,
+    DUMP_OUTPUT_PCAP = 0x1,
+    DUMP_OUTPUT_TEXT = 0x2,
+    DUMP_OUTPUT_BOTH = 0x3
+} DumpOutputType;
 
 typedef struct {
     // delegate most stuff to daq_pcap
@@ -44,7 +53,13 @@ typedef struct {
 
     // but write all output packets here
     pcap_dumper_t* dump;
-    char* name;
+    char* pcap_filename;
+
+    // and write other textual output here
+    FILE *text_out;
+    char* text_filename;
+
+    DumpOutputType output_type;
 
     // by linking in with these
     DAQ_Analysis_Func_t callback;
@@ -69,7 +84,26 @@ static int daq_dump_get_vars (
         }
         else if ( !strcmp(entry->key, "file") )
         {
-            impl->name = strdup(entry->value);
+            impl->pcap_filename = strdup(entry->value);
+        }
+        else if ( !strcmp(entry->key, "text-file") )
+        {
+            impl->text_filename = strdup(entry->value);
+        }
+        else if ( !strcmp(entry->key, "output") )
+        {
+            if ( !strcmp(entry->value, "none") )
+                impl->output_type = DUMP_OUTPUT_NONE;
+            else if ( !strcmp(entry->value, "pcap") )
+                impl->output_type = DUMP_OUTPUT_PCAP;
+            else if ( !strcmp(entry->value, "text") )
+                impl->output_type = DUMP_OUTPUT_TEXT;
+            else if ( !strcmp(entry->value, "both") )
+                impl->output_type = DUMP_OUTPUT_BOTH;
+            else
+            {
+                snprintf(errBuf, errMax, "invalid output type (%s)", entry->value);
+            }
         }
     }
     if ( !s )
@@ -94,6 +128,20 @@ static int daq_dump_get_vars (
     return 0;
 }
 
+static void hexdump(FILE *fp, const uint8_t *data, unsigned int len, const char *prefix)
+{
+    unsigned int i;
+    for (i = 0; i < len; i++)
+    {
+        if (i % 16 == 0)
+            fprintf(fp, "\n%s", prefix ? prefix : "");
+        else if (i % 2 == 0)
+            fprintf(fp, " ");
+        fprintf(fp, "%02x", data[i]);
+    }
+    fprintf(fp, "\n");
+}
+
 //-------------------------------------------------------------------------
 // constructor / destructor
 
@@ -110,16 +158,17 @@ static int dump_daq_initialize (
     {
         snprintf(errBuf, errMax,
             "%s: Couldn't allocate memory for the DAQ context",
-            __FUNCTION__);
+            __func__);
         return DAQ_ERROR_NOMEM;
     }
     if ( !mod || !(mod->type & DAQ_TYPE_FILE_CAPABLE) )
     {
-        snprintf(errBuf, errMax, "%s: no file capable daq provided", __FUNCTION__);
+        snprintf(errBuf, errMax, "%s: no file capable daq provided", __func__);
         free(impl);
         return DAQ_ERROR;
     }
 
+    impl->output_type = DUMP_OUTPUT_PCAP;
     if ( !daq_dump_get_vars(impl, &sub_cfg, errBuf, errMax) )
     {
         free(impl);
@@ -142,8 +191,10 @@ static void dump_daq_shutdown (void* handle)
 {
     DumpImpl* impl = (DumpImpl*)handle;
     impl->module->shutdown(impl->handle);
-    if ( impl->name )
-        free(impl->name);
+    if ( impl->pcap_filename )
+        free(impl->pcap_filename);
+    if ( impl->text_filename )
+        free(impl->text_filename);
     free(impl);
 }
 
@@ -151,6 +202,17 @@ static void dump_daq_shutdown (void* handle)
 // packet processing functions:
 // forward all but blocks, retries and blacklists:
 static const int s_fwd[MAX_DAQ_VERDICT] = { 1, 0, 1, 1, 0, 1, 0 };
+// We don't have access to daq_verdict_string() because we're not linking
+// against LibDAQ, so pack our own copy.
+static const char *daq_verdict_strings[MAX_DAQ_VERDICT] = {
+    "Pass",         // DAQ_VERDICT_PASS
+    "Block",        // DAQ_VERDICT_BLOCK
+    "Replace",      // DAQ_VERDICT_REPLACE
+    "Whitelist",    // DAQ_VERDICT_WHITELIST
+    "Blacklist",    // DAQ_VERDICT_BLACKLIST
+    "Ignore",       // DAQ_VERDICT_IGNORE
+    "Retry"         // DAQ_VERDICT_RETRY
+};
 
 static DAQ_Verdict daq_dump_capture (
     void* user, const DAQ_PktHdr_t* hdr, const uint8_t* pkt)
@@ -163,9 +225,17 @@ static DAQ_Verdict daq_dump_capture (
 
     impl->stats.verdicts[verdict]++;
 
-    if ( s_fwd[verdict] )
+    if ( impl->dump && s_fwd[verdict] )
         pcap_dump((u_char*)impl->dump, (struct pcap_pkthdr*)hdr, pkt);
 
+    if (impl->text_out)
+    {
+        fprintf(impl->text_out, "PV: %lu.%lu(%u): %s\n", (unsigned long) hdr->ts.tv_sec,
+                (unsigned long) hdr->ts.tv_usec, hdr->caplen, daq_verdict_strings[verdict]);
+        if (verdict == DAQ_VERDICT_REPLACE)
+            hexdump(impl->text_out, pkt, hdr->caplen, "    ");
+    }
+
     return verdict;
 }
 
@@ -184,18 +254,28 @@ static int dump_daq_inject (
 {
     DumpImpl* impl = (DumpImpl*)handle;
 
-    // copy the original header to get the same
-    // timestamps but overwrite the lengths
-    DAQ_PktHdr_t h = *hdr;
-
-    h.pktlen = h.caplen = len;
-    pcap_dump((u_char*)impl->dump, (struct pcap_pkthdr*)&h, data);
-
-    if ( ferror(pcap_dump_file(impl->dump)) )
+    if (impl->text_out)
     {
-        impl->module->set_errbuf(impl->handle, "inject can't write to dump file");
-        return DAQ_ERROR;
+        fprintf(impl->text_out, "%cI: %lu.%lu(%u): %u\n", reverse ? 'R' : 'F',
+                (unsigned long) hdr->ts.tv_sec, (unsigned long) hdr->ts.tv_usec, hdr->caplen, len);
+        hexdump(impl->text_out, data, len, "    ");
+        fprintf(impl->text_out, "\n");
     }
+
+    if (impl->dump)
+    {
+        // copy the original header to get the same
+        // timestamps but overwrite the lengths
+        DAQ_PktHdr_t h = *hdr;
+        h.pktlen = h.caplen = len;
+        pcap_dump((u_char*)impl->dump, (struct pcap_pkthdr*)&h, data);
+        if ( ferror(pcap_dump_file(impl->dump)) )
+        {
+            impl->module->set_errbuf(impl->handle, "inject can't write to dump file");
+            return DAQ_ERROR;
+        }
+    }
+
     impl->stats.packets_injected++;
     return DAQ_SUCCESS;
 }
@@ -205,8 +285,6 @@ static int dump_daq_inject (
 static int dump_daq_start (void* handle)
 {
     DumpImpl* impl = (DumpImpl*)handle;
-    const char* name = impl->name ? impl->name : DAQ_DUMP_FILE;
-    pcap_t* pcap;
     int dlt;
     int snap;
 
@@ -218,17 +296,35 @@ static int dump_daq_start (void* handle)
     dlt = impl->module->get_datalink_type(impl->handle);
     snap = impl->module->get_snaplen(impl->handle);
 
-    pcap = pcap_open_dead(dlt, snap);
-
-    impl->dump = pcap ? pcap_dump_open(pcap, name) : NULL;
-
-    if ( !impl->dump )
+    if ( impl->output_type & DUMP_OUTPUT_PCAP )
     {
-        impl->module->stop(impl->handle);
-        impl->module->set_errbuf(impl->handle, "can't open dump file");
-        return DAQ_ERROR;
+        const char* pcap_filename = impl->pcap_filename ? impl->pcap_filename : DAQ_DUMP_PCAP_FILE;
+        pcap_t* pcap;
+
+        pcap = pcap_open_dead(dlt, snap);
+        impl->dump = pcap ? pcap_dump_open(pcap, pcap_filename) : NULL;
+        if ( !impl->dump )
+        {
+            impl->module->stop(impl->handle);
+            impl->module->set_errbuf(impl->handle, "can't open dump file");
+            return DAQ_ERROR;
+        }
+        pcap_close(pcap);
     }
-    pcap_close(pcap);
+
+    if ( impl->output_type & DUMP_OUTPUT_TEXT )
+    {
+        const char* text_filename = impl->text_filename ? impl->text_filename : DAQ_DUMP_TEXT_FILE;
+
+        impl->text_out = fopen(text_filename, "w");
+        if ( !impl->text_out )
+        {
+            impl->module->stop(impl->handle);
+            impl->module->set_errbuf(impl->handle, "can't open text output file");
+            return DAQ_ERROR;
+        }
+    }
+
     return DAQ_SUCCESS;
 }
 
@@ -246,6 +342,12 @@ static int dump_daq_stop (void* handle)
         impl->dump = NULL;
     }
 
+    if ( impl->text_out )
+    {
+        fclose(impl->text_out);
+        impl->text_out = NULL;
+    }
+
     return DAQ_SUCCESS;
 }
 
@@ -328,6 +430,46 @@ static int dump_daq_get_device_index(void* handle, const char* device)
     return impl->module->get_device_index(impl->handle, device);
 }
 
+static int dump_daq_modify_flow(void *handle, const DAQ_PktHdr_t *hdr, const DAQ_ModFlow_t *modify)
+{
+    DumpImpl* impl = (DumpImpl*)handle;
+
+    if (impl->text_out)
+    {
+        fprintf(impl->text_out, "MF: %lu.%lu(%u): %d %u \n", (unsigned long) hdr->ts.tv_sec,
+                (unsigned long) hdr->ts.tv_usec, hdr->caplen, modify->type, modify->length);
+        hexdump(impl->text_out, modify->value, modify->length, "    ");
+    }
+    return DAQ_SUCCESS;
+}
+
+static int dump_daq_dp_add_dc(void *handle, const DAQ_PktHdr_t *hdr, DAQ_DP_key_t *dp_key,
+                                const uint8_t *packet_data, DAQ_Data_Channel_Params_t *params)
+{
+    DumpImpl* impl = (DumpImpl*)handle;
+
+    if (impl->text_out)
+    {
+        char src_addr_str[INET6_ADDRSTRLEN], dst_addr_str[INET6_ADDRSTRLEN];
+
+        fprintf(impl->text_out, "DP: %lu.%lu(%u):\n", (unsigned long) hdr->ts.tv_sec,
+                (unsigned long) hdr->ts.tv_usec, hdr->caplen);
+        if (dp_key->src_af == AF_INET)
+            inet_ntop(AF_INET, &dp_key->sa.src_ip4, src_addr_str, sizeof(src_addr_str));
+        else
+            inet_ntop(AF_INET6, &dp_key->sa.src_ip6, src_addr_str, sizeof(src_addr_str));
+        if (dp_key->dst_af == AF_INET)
+            inet_ntop(AF_INET, &dp_key->da.dst_ip4, dst_addr_str, sizeof(dst_addr_str));
+        else
+            inet_ntop(AF_INET6, &dp_key->da.dst_ip6, dst_addr_str, sizeof(dst_addr_str));
+        fprintf(impl->text_out, "    %s:%hu -> %s:%hu (%hhu)\n", src_addr_str, dp_key->src_port,
+                dst_addr_str, dp_key->dst_port, dp_key->protocol);
+        fprintf(impl->text_out, "    %hu %hu %hu %hu 0x%X %u\n", dp_key->address_space_id, dp_key->tunnel_type,
+                dp_key->vlan_id, dp_key->vlan_cnots, params ? params->flags : 0, params ? params->timeout_ms : 0);
+    }
+    return DAQ_SUCCESS;
+}
+
 //-------------------------------------------------------------------------
 
 #ifdef BUILDING_SO
@@ -357,10 +499,11 @@ DAQ_Module_t dump_daq_module_data =
     .get_errbuf = dump_daq_get_errbuf,
     .set_errbuf = dump_daq_set_errbuf,
     .get_device_index = dump_daq_get_device_index,
-    .modify_flow = NULL,
+    .modify_flow = dump_daq_modify_flow,
     .hup_prep = NULL,
     .hup_apply = NULL,
     .hup_post = NULL,
-    .dp_add_dc = NULL,
+    .dp_add_dc = dump_daq_dp_add_dc,
+    .query_flow = NULL,
 };
 
