@@ -1,5 +1,4 @@
 /*
- ** Portions Copyright (C) 2014-2015 Cisco and/or its affiliates. All rights reserved.
  ** Portions Copyright (C) 1998-2013 Sourcefire, Inc.
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -101,7 +100,7 @@ static int ipq_daq_get_setup (
         if ( !entry->value || !*entry->value )
         {
             snprintf(errBuf, errMax,
-                "%s: variable needs value (%s)\n", __FUNCTION__, entry->key);
+                "%s: variable needs value (%s)\n", __func__, entry->key);
                 return DAQ_ERROR;
         }
         else if ( !strcmp(entry->key, "proto") )
@@ -110,7 +109,7 @@ static int ipq_daq_get_setup (
             if ( !impl->proto )
             {
                 snprintf(errBuf, errMax, "%s: bad proto (%s)\n",
-                    __FUNCTION__, entry->value);
+                    __func__, entry->value);
                 return DAQ_ERROR;
             }
         }
@@ -121,7 +120,7 @@ static int ipq_daq_get_setup (
             {
                 snprintf(errBuf, errMax,
                     "%s: can't allocate memory for device (%s)\n",
-                    __FUNCTION__, entry->value);
+                    __func__, entry->value);
                 return DAQ_ERROR;
             }
         }
@@ -129,7 +128,7 @@ static int ipq_daq_get_setup (
         {
             snprintf(errBuf, errMax,
                 "%s: unsupported variable (%s=%s)\n",
-                    __FUNCTION__, entry->key, entry->value);
+                    __func__, entry->key, entry->value);
                 return DAQ_ERROR;
         }
     }
@@ -160,7 +159,7 @@ static int ipq_daq_initialize (
     if ( !impl )
     {
         snprintf(errBuf, errMax, "%s: failed to allocate the ipq context!",
-            __FUNCTION__);
+            __func__);
         return DAQ_ERROR_NOMEM;
     }
 
@@ -175,7 +174,7 @@ static int ipq_daq_initialize (
     if ( !impl->buf )
     {
         snprintf(errBuf, errMax, "%s: failed to allocate the ipq buffer!",
-            __FUNCTION__);
+            __func__);
         ipq_daq_shutdown(impl);
         return DAQ_ERROR_NOMEM;
     }
@@ -187,7 +186,7 @@ static int ipq_daq_initialize (
     if ( !impl->ipqh )
     {
         snprintf(errBuf, errMax, "%s: ipq_create_handle error %s\n",
-            __FUNCTION__, ipq_errstr());
+            __func__, ipq_errstr());
         ipq_daq_shutdown(impl);
         return DAQ_ERROR;
     }
@@ -199,7 +198,7 @@ static int ipq_daq_initialize (
     if ( status < 0 )
     {
         snprintf(errBuf, errMax, "%s: ipq_set_mode error %s\n",
-            __FUNCTION__, ipq_errstr());
+            __func__, ipq_errstr());
         ipq_daq_shutdown(impl);
         return DAQ_ERROR;
     }
@@ -210,7 +209,7 @@ static int ipq_daq_initialize (
         if ( !impl->link )
         {
             snprintf(errBuf, errMax, "%s: can't open %s!\n",
-                __FUNCTION__, impl->device);
+                __func__, impl->device);
             ipq_daq_shutdown(impl);
             return DAQ_ERROR;
         }
@@ -221,7 +220,7 @@ static int ipq_daq_initialize (
 
         if ( !impl->net )
         {
-            snprintf(errBuf, errMax, "%s: can't open ip!\n", __FUNCTION__);
+            snprintf(errBuf, errMax, "%s: can't open ip!\n", __func__);
             ipq_daq_shutdown(impl);
             return DAQ_ERROR;
         }
@@ -311,7 +310,7 @@ static int ipq_daq_acquire (
             if ( status < 0 )
             {
                 DPE(impl->error, "%s: ipq_read=%d error %s",
-                    __FUNCTION__, status, ipq_errstr());
+                    __func__, status, ipq_errstr());
                 return DAQ_ERROR;
             }
             return 0;
@@ -371,7 +370,7 @@ static int ipq_daq_acquire (
             if ( status < 0 )
             {
                 DPE(impl->error, "%s: ipq_set_verdict=%d error %s",
-                    __FUNCTION__, status, ipq_errstr());
+                    __func__, status, ipq_errstr());
                 return DAQ_ERROR;
             }
             n++;
@@ -381,7 +380,7 @@ static int ipq_daq_acquire (
             // NLMSG_ERROR is supposed to be the only other valid type
             status = ipq_get_msgerr(impl->buf);
             DPE(impl->error, "%s: ipq_message_type=%d error=%d %s",
-                __FUNCTION__, ipqt, status, ipq_errstr());
+                __func__, ipqt, status, ipq_errstr());
             // ipq_message_type=2 error=1 Timeout
             // keep looping upon timeout or other errors
         }
@@ -407,7 +406,7 @@ static int ipq_daq_inject (
     if ( (uint32_t)sent != len )
     {
         DPE(impl->error, "%s: failed to send",
-            __FUNCTION__);
+            __func__);
         return DAQ_ERROR;
     }
     impl->stats.packets_injected++;
@@ -425,7 +424,7 @@ static int ipq_daq_set_filter (void* handle, const char* filter)
     if (sfbpf_compile(impl->snaplen, dlt, &fcode, filter, 1, 0) < 0)
     {
         DPE(impl->error, "%s: failed to compile '%s'",
-            __FUNCTION__, filter);
+            __func__, filter);
         return DAQ_ERROR;
     }
 
