@@ -1,7 +1,7 @@
 /*
-** Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2010-2013 Sourcefire, Inc.
-** Author: Michael R. Altizer <maltizer@sourcefire.com>
+** Author: Michael R. Altizer <mialtize@cisco.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -41,6 +41,7 @@
 #include "daq_api.h"
 
 #define DAQ_PCAP_VERSION 3
+#define DAQ_PCAP_ROLLOVER_LIM 1000000000 //Check for rollover every billionth packet
 
 typedef struct _pcap_context
 {
@@ -66,6 +67,7 @@ typedef struct _pcap_context
     uint32_t wrap_recv;
     uint32_t wrap_drop;
     DAQ_State state;
+    uint32_t hwupdate_count;
 } Pcap_Context_t;
 
 static void pcap_daq_reset_stats(void *handle);
@@ -189,6 +191,7 @@ static int update_hw_stats(Pcap_Context_t *context)
 
         context->stats.hw_packets_received = context->rollover_recv + context->wrap_recv - context->base_recv;
         context->stats.hw_packets_dropped = context->rollover_drop + context->wrap_drop - context->base_drop;
+        context->hwupdate_count = 0;
     }
 
     return DAQ_SUCCESS;
@@ -204,7 +207,7 @@ static int pcap_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr, char
     context = calloc(1, sizeof(Pcap_Context_t));
     if (!context)
     {
-        snprintf(errbuf, len, "%s: Couldn't allocate memory for the new PCAP context!", __FUNCTION__);
+        snprintf(errbuf, len, "%s: Couldn't allocate memory for the new PCAP context!", __func__);
         return DAQ_ERROR_NOMEM;
     }
 
@@ -229,7 +232,7 @@ static int pcap_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr, char
         context->file = strdup(config->name);
         if (!context->file)
         {
-            snprintf(errbuf, len, "%s: Couldn't allocate memory for the filename string!", __FUNCTION__);
+            snprintf(errbuf, len, "%s: Couldn't allocate memory for the filename string!", __func__);
             free(context);
             return DAQ_ERROR_NOMEM;
         }
@@ -240,7 +243,7 @@ static int pcap_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr, char
         context->device = strdup(config->name);
         if (!context->device)
         {
-            snprintf(errbuf, len, "%s: Couldn't allocate memory for the device string!", __FUNCTION__);
+            snprintf(errbuf, len, "%s: Couldn't allocate memory for the device string!", __func__);
             free(context);
             return DAQ_ERROR_NOMEM;
         }
@@ -257,6 +260,7 @@ static int pcap_daq_initialize(const DAQ_Config_t *config, void **ctxt_ptr, char
         }
     }
 
+    context->hwupdate_count = 0;
     context->state = DAQ_STATE_INITIALIZED;
 
     *ctxt_ptr = context;
@@ -273,14 +277,14 @@ static int pcap_daq_set_filter(void *handle, const char *filter)
     {
         if (pcap_compile(context->handle, &fcode, (char *)filter, 1, context->netmask) < 0)
         {
-            DPE(context->errbuf, "%s: pcap_compile: %s", __FUNCTION__, pcap_geterr(context->handle));
+            DPE(context->errbuf, "%s: pcap_compile: %s", __func__, pcap_geterr(context->handle));
             return DAQ_ERROR;
         }
 
         if (pcap_setfilter(context->handle, &fcode) < 0)
         {
             pcap_freecode(&fcode);
-            DPE(context->errbuf, "%s: pcap_setfilter: %s", __FUNCTION__, pcap_geterr(context->handle));
+            DPE(context->errbuf, "%s: pcap_setfilter: %s", __func__, pcap_geterr(context->handle));
             return DAQ_ERROR;
         }
 
@@ -292,12 +296,12 @@ static int pcap_daq_set_filter(void *handle, const char *filter)
         dead_handle = pcap_open_dead(DLT_EN10MB, context->snaplen);
         if (!dead_handle)
         {
-            DPE(context->errbuf, "%s: Could not allocate a dead PCAP handle!", __FUNCTION__);
+            DPE(context->errbuf, "%s: Could not allocate a dead PCAP handle!", __func__);
             return DAQ_ERROR_NOMEM;
         }
         if (pcap_compile(dead_handle, &fcode, (char *)filter, 1, context->netmask) < 0)
         {
-            DPE(context->errbuf, "%s: pcap_compile: %s", __FUNCTION__, pcap_geterr(dead_handle));
+            DPE(context->errbuf, "%s: pcap_compile: %s", __func__, pcap_geterr(dead_handle));
             return DAQ_ERROR;
         }
         pcap_freecode(&fcode);
@@ -309,7 +313,7 @@ static int pcap_daq_set_filter(void *handle, const char *filter)
         context->filter_string = strdup(filter);
         if (!context->filter_string)
         {
-            DPE(context->errbuf, "%s: Could not allocate space to store a copy of the filter string!", __FUNCTION__);
+            DPE(context->errbuf, "%s: Could not allocate space to store a copy of the filter string!", __func__);
             return DAQ_ERROR_NOMEM;
         }
     }
@@ -359,6 +363,10 @@ static void pcap_process_loop(u_char *user, const struct pcap_pkthdr *pkth, cons
     context->packets++;
     /* ...and then the module instance's packet counter. */
     context->stats.packets_received++;
+    /* Update hw packet counters to make sure we detect counter overflow */
+    if (context->hwupdate_count++ == DAQ_PCAP_ROLLOVER_LIM)
+        update_hw_stats(context);
+
     verdict = context->analysis_func(context->user_data, &hdr, data);
     if (verdict >= MAX_DAQ_VERDICT)
         verdict = DAQ_VERDICT_PASS;
